pub enum ObjectArg {
ImmOrOwnedObject(ObjectRef),
SharedObject {
id: Address,
initial_shared_version: Version,
mutable: bool,
},
Receiving(ObjectRef),
}Expand description
Object argument for a programmable transaction.
This type is here for backwards compatibility purposes; specifically to use in our programmable
transaction builder. The actual ProgrammableTransaction does not contain this type.
Variants
ImmOrOwnedObject(ObjectRef)
A Move object from fastpath.
A Move object from consensus (historically consensus objects were always shared).
SharedObject::mutable controls whether caller asks for a mutable reference to shared object.
Receiving(ObjectRef)
A Move object that can be received in this transaction.
Implementations
Sourceimpl ObjectArg
impl ObjectArg
Sourcepub const CLOCK_IMM: Self
pub const CLOCK_IMM: Self
Argument for transactions acquiring an immutable reference to the network clock.
Only system transactions acquire mutable references to the clock.
Sourcepub const SYSTEM_STATE_IMM: Self
pub const SYSTEM_STATE_IMM: Self
Argument for transactions acquiring an immutable reference to the system state.
Sourcepub const SYSTEM_STATE_MUT: Self
pub const SYSTEM_STATE_MUT: Self
Argument for transactions acquiring a mutable reference to the system state.
pub const fn id(&self) -> Address
pub const fn id_borrowed(&self) -> &Address
Sourcepub fn set_mutable(
&mut self,
mutable_: bool,
) -> Result<(), ImmOwnedOrReceivingError>
pub fn set_mutable( &mut self, mutable_: bool, ) -> Result<(), ImmOwnedOrReceivingError>
For shared object arguments: set their mutable flag value.