Enum TransactionData

pub enum TransactionData {
    V1(TransactionDataV1),
}
The payload that gets sent to the full node as base64 BCS bytes.

Variants

Implementations

Source

impl TransactionData

pub fn digest(&self) -> TransactionDigest

Available on crate feature hash only.
Source

impl TransactionData

pub fn signing_digest(&self) -> SigningDigest

Available on crate feature hash only.
Source

impl TransactionData

pub const fn v1( kind: TransactionKind, sender: Address, gas_data: GasData, expiration: TransactionExpiration, ) -> Self

Create a new transaction (V1).

pub const fn as_v1(&self) -> &TransactionDataV1

Get the underlying variant.

Since the enum is not #[non_exhaustive] today, this returns a reference. If and when a new version is introduced, there will have to be a SemVer-breaking update anyway and this method will return an option.

pub fn encode_base64(&self) -> String

The payload that gets sent to the full node.

pub fn decode_base64( &self, value: impl AsRef<[u8]>, ) -> Result<Self, TransactionFromBase64Error>

👎Deprecated: Unnecessary &self; will be removed with the next breaking change

Deserialize a transaction from base64 bytes.