pub struct CheckpointData {
pub checkpoint_summary: SignedCheckpointSummary,
pub checkpoint_contents: CheckpointContents,
pub transactions: Vec<CheckpointTransaction>,
}Fields
checkpoint_summary: SignedCheckpointSummarycheckpoint_contents: CheckpointContentstransactions: Vec<CheckpointTransaction>Implementations
Sourceimpl CheckpointData
impl CheckpointData
Sourcepub fn latest_live_output_objects(&self) -> Vec<&Object>
pub fn latest_live_output_objects(&self) -> Vec<&Object>
The latest versions of the output objects that still exist at the end of the checkpoint
Sourcepub fn eventually_removed_object_refs_post_version(
&self,
) -> Vec<ObjectReference>
pub fn eventually_removed_object_refs_post_version( &self, ) -> Vec<ObjectReference>
The object refs that are eventually deleted or wrapped in the current checkpoint