pub struct CheckpointTransaction {
pub transaction: SignedTransaction,
pub effects: TransactionEffects,
pub events: Option<TransactionEvents>,
pub input_objects: Vec<Object>,
pub output_objects: Vec<Object>,
}Fields
transaction: SignedTransactionThe input Transaction
effects: TransactionEffectsThe effects produced by executing this transaction
events: Option<TransactionEvents>The events, if any, emitted by this transaction during execution
input_objects: Vec<Object>The state of all inputs to this transaction as they were prior to execution.
output_objects: Vec<Object>The state of all output objects created or mutated or unwrapped by this transaction.
Implementations
Sourceimpl CheckpointTransaction
impl CheckpointTransaction
Sourcepub const fn transaction_data(&self) -> &Transaction
pub const fn transaction_data(&self) -> &Transaction
The unsigned transaction payload.