pub struct MoveObject {
pub type_: MoveObjectType,
pub version: Version,
pub contents: Vec<u8>,
/* private fields */
}Fields
type_: MoveObjectTypeThe type of this object. Immutable
version: VersionNumber that increases each time a tx takes this object as a mutable input This is a lamport timestamp, not a sequentially increasing version
contents: Vec<u8>BCS bytes of a Move struct value
Implementations
Sourceimpl MoveObject
impl MoveObject
Sourcepub fn id(&self) -> ObjectId
pub fn id(&self) -> ObjectId
Get the object’s ID from its BCS serialization.
Panics
This will panic if the BCS contents do not enconde a MoveObject.