Struct Object

pub struct Object {
    pub owner: Owner,
    pub previous_transaction: TransactionDigest,
    pub storage_rebate: u64,
    /* private fields */
}
Alias of sui_types::object::ObjectInner, skipping the Arc in sui_types::object::Object.

Fields

owner: Owner

The owner that unlocks this object

previous_transaction: TransactionDigest

The digest of the transaction that created or last mutated this object

storage_rebate: u64

The amount of SUI we would rebate if this object gets deleted. This number is re-calculated each time the object is mutated based on the present storage gas price.

Implementations

Source

impl Object

pub fn digest(&self) -> ObjectDigest

Available on crate feature hash only.
pub fn object_arg(&self, mutable: bool) -> ObjectArg

Available on crate feature hash only.

Input for transactions that interact with this object.

Source

impl Object

pub fn id(&self) -> ObjectId

Its unique on-chain identifier.

pub const fn version(&self) -> Version

Its current version.

pub const fn as_move(&self) -> Option<&MoveObject>

Reference to the underlying Move object, if it is one.

pub const fn as_package(&self) -> Option<&MovePackage>

Reference to the underlying Move package, if it is one.

pub fn into_move(self) -> Option<MoveObject>

Convert to the underlying Move object, if it is one.

pub fn into_package(self) -> Option<MovePackage>

Convert to the underlying Move package, if it is one.