pub type ObjectRef = (Address, Version, Digest);Expand description
Reference to a particular object.
Used for immutable or owned object transaction inputs (fast-path).
Can be created from ObjectReference::into_parts.
pub type ObjectRef = (Address, Version, Digest);Reference to a particular object.
Used for immutable or owned object transaction inputs (fast-path).
Can be created from ObjectReference::into_parts.