IdentStr

Struct IdentStr 

pub struct IdentStr(/* private fields */);
A borrowed identifier.

For more details, see the module level documentation.

Implementations

Source

impl IdentStr

pub fn new(s: &str) -> Result<&IdentStr, InvalidIdentifierError>

pub const fn cast(s: &'static str) -> &'static IdentStr

Compile-time validated constructor from static string slice.

Example

Creating a valid static or const IdentStr:

use af_sui_types::IdentStr;
const VALID_IDENT: &'static IdentStr = IdentStr::cast("MyCoolIdentifier");

const THING_NAME: &'static str = "thing_name";
const THING_IDENT: &'static IdentStr = IdentStr::cast(THING_NAME);

In contrast, creating an invalid IdentStr will fail at compile time:

use af_sui_types::IdentStr;
const INVALID_IDENT: &'static IdentStr = IdentStr::cast("123Foo"); // Fails to compile!
pub fn is_valid(s: impl AsRef<str>) -> bool

Returns true if this string is a valid identifier.

pub const fn len(&self) -> usize

Returns the length of self in bytes.

pub const fn is_empty(&self) -> bool

Returns true if self has a length of zero bytes.

pub const fn as_str(&self) -> &str

Converts self to a &str.

This is not implemented as a From trait to discourage automatic conversions – these conversions should not typically happen.

pub const fn as_bytes(&self) -> &[u8]

Converts self to a byte slice.