pub trait TransactionDataAPI {
Show 15 methods
// Required methods
fn sender(&self) -> Address;
fn kind(&self) -> &TransactionKind;
fn kind_mut(&mut self) -> &mut TransactionKind;
fn into_kind(self) -> TransactionKind;
fn gas_data(&self) -> &GasData;
fn gas_owner(&self) -> Address;
fn gas(&self) -> &[ObjectRef];
fn gas_price(&self) -> u64;
fn gas_budget(&self) -> u64;
fn expiration(&self) -> &TransactionExpiration;
fn is_system_tx(&self) -> bool;
fn is_genesis_tx(&self) -> bool;
fn is_end_of_epoch_tx(&self) -> bool;
fn is_sponsored_tx(&self) -> bool;
fn gas_data_mut(&mut self) -> &mut GasData;
}Required Methods
fn sender(&self) -> Address
fn kind(&self) -> &TransactionKind
fn kind_mut(&mut self) -> &mut TransactionKind
fn into_kind(self) -> TransactionKind
fn gas_data(&self) -> &GasData
fn gas_owner(&self) -> Address
fn gas(&self) -> &[ObjectRef]
fn gas_price(&self) -> u64
fn gas_budget(&self) -> u64
fn expiration(&self) -> &TransactionExpiration
fn is_system_tx(&self) -> bool
fn is_genesis_tx(&self) -> bool
Sourcefn is_end_of_epoch_tx(&self) -> bool
fn is_end_of_epoch_tx(&self) -> bool
returns true if the transaction is one that is specially sequenced to run at the very end of the epoch
Sourcefn is_sponsored_tx(&self) -> bool
fn is_sponsored_tx(&self) -> bool
Check if the transaction is sponsored (namely gas owner != sender)